#include <genvector/vtp0.h>
#include <genvector/gds_char.h>
#include <librnd/core/color.h>
#define GVT_DONT_UNDEF
#include "vtpadstack_t.h"
#include <genvector/genvector_impl.c>
